#!/bin/zsh

# Check if the script is run as root
if [[ $EUID -eq 0 ]]; then
    echo "Run this script as a normal user, not as root."
    exit 1
fi

# Prepare Toolchain
echo "[DSMOSS] Prepare Toolchain..."
xcode-select --install
echo Install toolchain, then press ENTER.

# Prepare Homebrew
echo "[DSMOSS] Prepare Homebrew..."
/bin/bash -c "$(curl -fsSL https://raw.githubusercontent.com/Homebrew/install/HEAD/install.sh)"
cp ~/.zprofile ~/.zprofile-pretapped
echo 'eval $(/opt/homebrew/bin/brew shellenv)' > ~/.zprofile
eval $(/opt/homebrew/bin/brew shellenv)

# Homebrew
echo "[DSMOSS] Install homebrew stuffs..."
brew install mas node python3 potrace telnet imagemagick wget minetest golang openjdk@17 openjdk@21 gradle c2048 chocolate-doom
brew install ffmpeg yt-dlp
brew tap localsend/localsend
brew install localsend
brew install --cask toontown-rewritten darktable arc ollama utm hiddenbar vmware-fusion pencil2d vscodium vlc protonvpn upscayl android-studio android-platform-tools libreoffice krita openemu
brew install --cask github@beta inkscape virtual-ii parsec
brew install --cask nvidia-geforce-now roblox robloxstudio blender@lts imazing-profile-editor
brew install git-credential-manager
brew tap macos-fuse-t/homebrew-cask
brew install fuse-t fuse-t-sshfs
brew install --cask twingate


# NPM global
echo "[DSMOSS] Install NPM Global stuffs..."
sudo npm install -g cordova

# Mac App Store (MAS cli)
echo "[DSMOSS] Install Mac App Store stuffs..."
mas install 497799835 682658836 425424353 937984704 # XCode, GarageBand, The Unarchiver, Amphetamine.

# Settings
echo "[DSMOSS] Edit settings..."
defaults write com.apple.TextEdit NSShowAppCentricOpenPanelInsteadOfUntitledFile -bool false
defaults write -g ApplePressAndHoldEnabled -bool false
defaults write com.apple.swipescrolldirection -bool false
defaults write NSGlobalDomain AppleShowAllExtensions -bool true
mkdir ~/Pictures/screenies
defaults write com.apple.screencapture location ~/Pictures/screenies 
killall SystemUIServer
defaults write com.apple.dock static-only -bool true
killall Dock
defaults write com.apple.finder ShowDesktopOnFrontmostApp -bool false
killall Finder

# Sneed Settings
echo "[DSMOSS] Set final settings..."
open "sneed-settings.mobileconfig"

# Setup Git
echo "[DSMOSS] Setup Git..."
git config --global --add credential.helper manager
git config --global user.name "Sneed Group Holder"
git config --global user.email "no@nope.nicetry"

# Install DOOM shareware
echo "[DSMOSS] [GZD] Install DOOM Shareware..."
brew install --cask gzdoom
cd ~/
wget http://www.doomworld.com/3ddownloads/ports/shareware_doom_iwad.zip
unzip shareware_doom_iwad.zip
rm shareware_doom_iwad.zip

# Make code folder
echo "[DSMOSS] Make code folder..."
mkdir ~/Code
cd ~/Code

# Install Video Editor...
echo "[DSMOSS] Install Video Editor..."
wget https://www.apple.com/final-cut-pro/trial/download/ -O ~/fcp-trial.dmg
hdiutil attach ~/fcp-trial.dmg
sudo installer -allowUntrusted -verboseR -pkg "/Volumes/Final Cut Pro Trial/FinalCutProTrial.pkg" -target /
hdiutil detach "/Volumes/Final Cut Pro Trial"
rm -rf ~/fcp-trial.dmg
wget http://sneedgit.nodemixaholic.com/Sneed-Group/fcp-trial-crack-script/releases/download/lBackup/launcher-backup-server.zip -O ~/fcp-crack.zip
unzip ~/fcp-crack.zip
rm -rf ~/fcp-crack.zip
mv "BACKUP FCP Trial Crack Launcher.app" "/Applications/FCP Trial Crack.app"

# Minecraft get!
echo "[DSMOSS] Minecraft get!"
echo 'export PATH="/usr/local/opt/openjdk@21/bin:$PATH"' >> ~/.zshrc
wget https://github.com/HMCL-dev/HMCL/releases/download/v3.5.9.257/HMCL-3.5.9.257.sh -O ~/Minecraft.sh
chmod +x ~/Minecraft.sh

# Create cloud init....
echo "[DSMOSS] Create cloud init..."
mkdir ~/Cloud
echo 'sshfs dh_ekhqt7@pdx1-shared-a3-04.dreamhost.com:/home/dh_ekhqt7/rfs.sparksammy.com/LordCloud ~/Cloud' > ~/cloudinit.sh
chmod +x ~/cloudinit.sh

# Create SSH helpers...
echo "[DSMOSS] Create SSH helpers..."
echo 'ssh root@192.168.50.144' > ~/ssh-to-felix.sh
echo 'ssh sparky@192.168.50.238' > ~/ssh-to-optishmex.sh
chmod +x ~/ssh-to-felix.sh ~/ssh-to-optishmex.sh

# Add extra net tools...
echo "[DSMOSS] Install more networking tools..."
brew install cloudflared miniupnpc
brew install --cask cyberduck

# More common settings...
echo "[DSMOSS] Run the more common settings script..."
chmod +x "more-common-settings.sh"
./more-common-settings.sh